import React, { useCallback, useMemo } from 'react';
import { HandleLinkPressFeature, ForceResponsiveViewportFeature, useWebshell } from '@formidable-webview/webshell';
import { linkPressTargetToOnDOMLinkPressArgs } from '@native-html/plugins-core';
/**
 * Configuration options for the HTMLIframe component.
 * You can pass those options through `renderersProps.iframe`
 * HTML prop.
 *
 * @public
 */

const features = [new HandleLinkPressFeature({
  preventDefault: true
})];
/**
 * A component to render iframes in react-native-render-html.
 *
 * @public
 */

export default function HTMLIframe({
  WebView,
  webViewProps: userWebViewProps,
  source,
  style,
  onLinkPress,
  scaleFactor,
  scalesPageToFit = false
}) {
  const scaleFeature = useMemo(() => scalesPageToFit ? new ForceResponsiveViewportFeature({
    initScale: scaleFactor,
    maxScale: scaleFactor,
    minScale: scaleFactor
  }) : null, [scaleFactor, scalesPageToFit]);
  const onDOMLinkPress = useCallback(event => onLinkPress === null || onLinkPress === void 0 ? void 0 : onLinkPress.apply(null, linkPressTargetToOnDOMLinkPressArgs(event)), [onLinkPress]);
  const webViewProps = useWebshell({
    features: [...features, scaleFeature],
    props: { ...userWebViewProps,
      onDOMLinkPress,
      style,
      source,
      testID: 'iframe'
    }
  });
  return /*#__PURE__*/React.createElement(WebView, webViewProps);
}
//# sourceMappingURL=HTMLIframe.js.map